var interfacecom_1_1sun_1_1star_1_1style_1_1XAutoStyleFamily =
[
    [ "com::sun::star::container::XEnumerationAccess", "interfacecom_1_1sun_1_1star_1_1style_1_1XAutoStyleFamily.html#a129dd133e3d7ef2600cb122d60282288", null ],
    [ "insertStyle", "interfacecom_1_1sun_1_1star_1_1style_1_1XAutoStyleFamily.html#afaf74a9d6796dc712a903dbd6c69a2a2", null ]
];